@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,7 +32,7 @@ class FilterActionMissingIdentityDialog : public QDialog
 public:
     explicit FilterActionMissingIdentityDialog(const QString &filtername, QWidget *parent = nullptr);
     ~FilterActionMissingIdentityDialog();
-    int selectedIdentity() const;
+    Q_REQUIRED_RESULT int selectedIdentity() const;
 
 private:
     void writeConfig();
